@@ -27,6 +27,7 @@ from pykechain.exceptions import (
     APIError,
 )
 from pykechain.models import Activity
+from pykechain.models.representations import CustomIconRepresentation
 from pykechain.utils import temp_chdir, slugify_ref
 from tests.classes import TestBetamax
 from tests.utils import TEST_FLAG_IS_WIM2
@@ -72,6 +73,11 @@ class TestActivityConstruction(TestBetamax):
             due_date=self.time,
             activity_type=activity_type,
             classification=classification,
+            activity_options=dict(
+                representations=[
+                    CustomIconRepresentation(value="pennant").as_json(),
+                ],
+            ),
         )
 
         # testing
@@ -744,6 +750,19 @@ class TestActivities(TestBetamax):
         for child in children:
             self.assertEqual(child._json_data.get("parent_id"), subprocess.id)
 
+    def test_count_children(self):
+        process = self.project.activity(name="Tasks with Widgets")
+        nr = process.count_children()
+
+        self.assertIsInstance(nr, int)
+        self.assertEqual(7, nr)
+
+        nr = process.count_children(name__contains="Service")
+        self.assertEqual(4, nr)
+
+        with self.assertRaises(IllegalArgumentError):
+            self.task.count_children()
+
     def test_rootlevel_activity_is_rootlevel(self):
         specify_wd = self.project.activity("Specify wheel diameter")
 
@@ -888,14 +907,16 @@ class TestActivityDownloadAsPDF(TestBetamax):
 
         # testing
         with temp_chdir() as target_dir:
-            activity.download_as_pdf(target_dir=target_dir, pdf_filename="pdf_file")
-            activity.download_as_pdf(target_dir=target_dir)
-            pdf_file = os.path.join(target_dir, "pdf_file.pdf")
-            pdf_file_called_after_activity = os.path.join(
-                target_dir, activity_name + ".pdf"
+            pdf_file = activity.download_as_pdf(
+                target_dir=target_dir,
+                pdf_filename="pdf_file",
             )
-            self.assertTrue(pdf_file)
-            self.assertTrue(pdf_file_called_after_activity)
+            self.assertTrue(os.path.exists(pdf_file))
+
+            pdf_file_called_after_activity = activity.download_as_pdf(
+                target_dir=target_dir,
+            )
+            self.assertTrue(os.path.exists(pdf_file_called_after_activity))
 
     @pytest.mark.skipif(
         "os.getenv('TRAVIS', False) or os.getenv('GITHUB_ACTIONS', False)",
@@ -907,15 +928,13 @@ class TestActivityDownloadAsPDF(TestBetamax):
 
         # testing
         with temp_chdir() as target_dir:
-            activity.download_as_pdf(
-                target_dir=target_dir, pdf_filename="pdf_file", include_appendices=True
+            pdf_file = activity.download_as_pdf(
+                target_dir=target_dir,
+                pdf_filename="pdf_file",
+                include_appendices=True,
+                include_qr_code=True,
             )
-            pdf_file = os.path.join(target_dir, "pdf_file.pdf")
-            pdf_file_called_after_activity = os.path.join(
-                target_dir, activity_name + ".pdf"
-            )
-            self.assertTrue(pdf_file)
-            self.assertTrue(pdf_file_called_after_activity)
+            self.assertTrue(os.path.exists(pdf_file))
 
     def test_activity_share_link(self):
         # setUp
@@ -929,7 +948,9 @@ class TestActivityDownloadAsPDF(TestBetamax):
         activity = self.project.activity(name=activity_name)
 
         activity.share_link(
-            subject=subject, message=message, recipient_users=recipient_users
+            subject=subject,
+            message=message,
+            recipient_users=recipient_users,
         )
 
         # testing
@@ -964,6 +985,7 @@ class TestActivityDownloadAsPDF(TestBetamax):
             paper_size=paper_size,
             paper_orientation=paper_orientation,
             include_appendices=False,
+            include_qr_code=True,
         )
 
         # testing
