@@ -1,3 +1,4 @@
+import os
 from datetime import datetime
 
 from pykechain.enums import Multiplicity, PropertyType
@@ -45,17 +46,23 @@ class TestPartsCopyMove(TestBetamax):
             # options={S},
             property_type=PropertyType.REFERENCES_VALUE
         )
-        sub_part1 = self.model_to_be_copied.add_model(
+        self.sub_part1 = self.model_to_be_copied.add_model(
             name="__subpart 1",
             multiplicity=Multiplicity.ONE
         )
-        sub_part2 = self.model_to_be_copied.add_model(
+        self.sub_part2 = self.model_to_be_copied.add_model(
             name="__subpart 2",
-            multiplicity=Multiplicity.ONE
+            multiplicity=Multiplicity.ZERO_MANY
+        )
+        self.sub_part2.add_property(
+            name="__Property boolean",
+            default_value=False,
+            property_type=PropertyType.BOOLEAN_VALUE,
         )
 
         self.model_target_parent = self.project.model(ref='bike')
         self.instance_to_be_copied = self.model_to_be_copied.instances()[0]
+        self.instance_to_be_copied.add(model=self.sub_part2)
         self.instance_target_parent = self.model_to_be_copied.parent().instances()[0]
         self.dump_part = None
 
@@ -96,7 +103,7 @@ class TestPartsCopyMove(TestBetamax):
         )
         bike_part = self.project.part('Bike')
 
-        copied_instance = [child for child in bike_part.children() if 'to be Copied' in child.name][0]
+        copied_instance = [child for child in bike_part.children() if 'Copied' in child.name][0]
         copied_instance.populate_descendants()
 
         # testing
@@ -128,6 +135,54 @@ class TestPartsCopyMove(TestBetamax):
         self.assertEqual(len(copied_model.properties), 5)
         self.assertEqual(len(copied_model._cached_children), 0)
 
+    def test_copy_internal_references_on_model(self):
+        child_model = self.model_to_be_copied.children()[0]
+        self.model_to_be_copied.add_property(
+            name='__Property internal reference',
+            default_value=child_model,
+            # options={S},
+            property_type=PropertyType.REFERENCES_VALUE
+        )
+
+        model_target_parent = self.project.model('Bike')
+        self.dump_part = self.model_to_be_copied.copy(
+            target_parent=model_target_parent,
+            name='__Copied model under Bike',
+            include_children=True,
+            include_instances=False
+        )
+
+        copied_child = self.dump_part.children()[0]
+        reference_property = self.dump_part.property(name="__Property internal reference")
+
+        self.assertEqual(copied_child, reference_property.value[0])
+
+    def test_copy_internal_references_on_instance(self):
+        prop_name = "__Property internal reference"
+        child_model = self.model_to_be_copied.children()[0]
+        self.model_to_be_copied.add_property(
+            name=prop_name,
+            default_value=child_model,
+            property_type=PropertyType.REFERENCES_VALUE
+        )
+
+        self.instance_to_be_copied.refresh()  # to load the new property
+        self.instance_to_be_copied.property(name=prop_name).value = self.instance_to_be_copied.children()[0]
+
+        instance_target_parent = self.project.part('Bike')
+        copied_instance = self.instance_to_be_copied.copy(
+            target_parent=instance_target_parent,
+            name='__Copied instance under Bike',
+            include_children=True,
+        )
+        self.dump_part = copied_instance.model()
+
+        copied_child = copied_instance.children()[0]
+        reference_property = copied_instance.property(name=prop_name)
+
+        self.assertTrue(reference_property.has_value())
+        self.assertEqual(copied_child, reference_property.value[0])
+
     def test_move_part_model(self):
         # setUp
         model_target_parent = self.project.model('Bike')
@@ -207,3 +262,61 @@ class TestPartsCopyMove(TestBetamax):
 
         with self.assertRaisesRegex(IllegalArgumentError, 'must have the same category'):
             self.model_to_be_copied.move(target_parent=target_instance)
+
+    def test_copy_target_parent_inside_tree(self):
+        with self.assertRaises(IllegalArgumentError):
+            self.model_to_be_copied.copy(
+                target_parent=self.sub_part1,
+            )
+
+    def test_copy_missing_target_parent_instance(self):
+        target_parent = self.project.product_root_model.add_model(
+            name="__ZERO+ MODEL", multiplicity=Multiplicity.ZERO_MANY,
+        )
+        self.dump_part = target_parent
+        with self.assertRaises(IllegalArgumentError):
+            self.model_to_be_copied.copy(
+                target_parent=target_parent,
+                include_instances=True,
+            )
+
+    def test_copy_too_many_target_parent_instances(self):
+        target_parent = self.project.product_root_model.add_model(
+            name="__ONE+ MODEL", multiplicity=Multiplicity.ONE_MANY,
+        )
+        self.project.product_root_instance.add(model=target_parent)
+        self.dump_part = target_parent
+        with self.assertRaises(IllegalArgumentError):
+            self.model_to_be_copied.copy(
+                target_parent=target_parent,
+                include_instances=True,
+            )
+
+    def test_copy_attachments(self):
+        names = [
+            "__Property attachment_1",
+            "__Property attachment_2",
+        ]
+
+        for name in names:
+            self.model_to_be_copied.add_property(
+                name=name,
+                property_type=PropertyType.ATTACHMENT_VALUE,
+            )
+
+        self.instance_to_be_copied.refresh()
+
+        for name in names:
+            p_attachment = self.instance_to_be_copied.property(name)
+            file = os.path.join(os.path.dirname(os.path.dirname(__file__)), "requirements.txt")
+            p_attachment.upload(file)
+
+        self.dump_part = self.model_to_be_copied.copy(
+            target_parent=self.model_target_parent,
+        )
+
+        copied_instance = self.dump_part.instance()
+
+        for name in names:
+            copied_prop = copied_instance.property(name)
+            self.assertTrue(copied_prop.has_value())
